@@ -6,6 +6,15 @@ from scipy.stats import norm
 
 from typing import Union
 
+from tscausalinference.seasonality import yearly_season, weekly_season
+
+import warnings
+warnings.simplefilter(action='ignore', category=FutureWarning)
+
+def min_max_scale(data, min_range, max_range):
+    data_min, data_max = data.min(), data.max()
+    return (data - data_min) * (max_range - min_range) / (data_max - data_min) + min_range
+
 def prob_in_distribution(data, x):
   """
     Calculate the probability of a given value being in a distribution defined by the given data.
@@ -42,9 +51,11 @@ def prob_in_distribution(data, x):
           return 2 * (1 - cdf_x + cdf_lower) / (1 - cdf_lower - cdf_upper)
 
 def bootstrap_simulate(
-                    data: Union[np.array, pd.DataFrame] = None, 
+                    variable: Union[np.array, pd.DataFrame] = None, 
                     n_samples: int = 1500, 
-                    n_steps: int = None):
+                    n_steps: int = None,
+                    mape: float = None,
+                    prio = False):
     """
     Generate an array of bootstrap samples for a given dataset.
 
@@ -75,21 +86,37 @@ def bootstrap_simulate(
     
     # Loop over number of bootstrap samples
     for i in range(n_samples):
+        min_range = variable.min() * (1 - mape)
+        max_range = variable.max() * (mape + 1)
+
         # Resample data with replacement
-        bootstrap_data = np.random.choice(data, size=len(data))#, replace=True)
+        bootstrap_data = np.random.choice(variable, size=len(variable))#, replace=True)
         
         # Simulate random walk based on bootstrap data
         walk = np.cumsum(np.random.randn(n_steps))
         walk -= walk[0]
+
         walk *= bootstrap_data.std() / walk.std()
         walk += bootstrap_data.mean()
 
         # Smooth the simulated random walk using a moving average filter
         smoother = 2  # the amount of smoothing on either side
-        walk_smoothed = np.convolve(walk, np.ones(2*smoother+1)/(2*smoother+1), mode='valid')
         
-        # Save random walk as one of the bootstrap samples
-        bootstrap_samples[i] = walk_smoothed
+        # Pad the beginning and end of the input array
+        pad_size = smoother
+        padded_walk = np.pad(walk, (pad_size, pad_size), mode='edge')
+        
+        # Apply the smoothing filter
+        walk_smoothed = np.convolve(padded_walk, np.ones(2*smoother+1)/(2*smoother+1), mode='valid')
+        walk = walk_smoothed.copy()
+
+        if prio:
+            info = variable.values
+            walk = info + (np.mean(walk) - np.mean(info))
+
+        # Limiting the walk and Save random walk as one of the bootstrap samples
+        walk = min_max_scale(walk, min_range, max_range)
+        bootstrap_samples[i] = walk.copy()
     
     return bootstrap_samples
     
@@ -97,8 +124,8 @@ def bootstrap_p_value(
                     control: Union[np.array, pd.DataFrame] = None, 
                     treatment: Union[np.array, pd.DataFrame] = None, 
                     simulations: np.array = None, 
-                    alpha: float = 0.05,
-                    mape: float = None):
+                    alpha: float = 0.05
+                    ):
     """
     Calculate the p-value for a difference in means between 
     a control group and a treatment group using the bootstrap method.
@@ -146,10 +173,6 @@ def bootstrap_p_value(
     for i in range(len(simulations)):
         bootstrapped_means[i] = simulations[i].mean()
     
-    bootstrapped_means_min = bootstrapped_means - (mean * mape)
-    bootstrapped_means_max = bootstrapped_means + (mean * mape)
-    bootstrapped_means = np.concatenate([bootstrapped_means_min, bootstrapped_means, bootstrapped_means_max])
-    
     lower, upper = np.percentile(bootstrapped_means, [alpha / 2 * 100, (1 - alpha / 2) * 100])
     
     p_value = prob_in_distribution(bootstrapped_means, mean_treatment)
